
{*******************************************************}
{                                                       }
{       AnimatedMenus/2000                              }
{       Menu options class unit                         }
{                                                       }
{       Copyright (c) 1998 by Andrew Cher               }
{                                                       }
{*******************************************************}


unit am2000options;

interface

uses
  Classes, Graphics, Menus, Controls,
  am2000title;

type
  T_AM2000_Alignment = (taLeftJustify, taRightJustify, taCenter, taHebrew);

  // animation effect
  T_AM2000_Animation = (anNone, anVSlide, anHSlide, anSmart, anUnfold, anPopup, anRandom);

  // highlighting style
  T_AM2000_HighlightingStyle = (hsDefault, hsRectangle, hsBevelLowered, hsBevelRaised, hsShadow,
    hsHyperlink, hsFlash, hsShsning);

  // menu margins
  T_AM2000_Margins = class(TPersistent)
  private
    FLeft      : Integer;
    FTop       : Integer;
    FRight     : Integer;
    FBottom    : Integer;
    FItemSpace : Integer;

  public
    constructor Create;
    procedure Assign(Source: TPersistent); override;

  published
    property Left      : Integer read FLeft      write FLeft      default 25;
    property Top       : Integer read FTop       write FTop       default 1;
    property Right     : Integer read FRight     write FRight     default 25;
    property Bottom    : Integer read FBottom    write FBottom    default 1;
    property ItemSpace : Integer read FItemSpace write FItemSpace default 0;

  end;


  // menu colors
  T_AM2000_Colors = class(TPersistent)
  private
    FBorder          : TColor;
    FMenu            : TColor;
    FMenuText        : TColor;
    FMenuShadow      : TColor;
    FHighlight       : TColor;
    FHighlightText   : TColor;
    FDisabledText    : TColor;
    FDisabledShadow  : TColor;
    FLine            : TColor;
    FLineShadow      : TColor;

  public
    constructor Create;
    procedure Assign(Source: TPersistent); override;
    function IsDefaultColors: Boolean;
//    function CompareColors(Source: T_AM2000_Colors): Boolean;

  published
    property Border         : TColor   read FBorder         write FBorder         default clNone;
    property Menu           : TColor   read FMenu           write FMenu           default clMenu;
    property MenuText       : TColor   read FMenuText       write FMenuText       default clMenuText;
    property MenuShadow     : TColor   read FMenuShadow     write FMenuShadow     default clBtnShadow;
    property Highlight      : TColor   read FHighlight      write FHighlight      default clHighlight;
    property HighlightText  : TColor   read FHighlightText  write FHighlightText  default clHighlightText;
    property DisabledText   : TColor   read FDisabledText   write FDisabledText   default clBtnShadow;
    property DisabledShadow : TColor   read FDisabledShadow write FDisabledShadow default clBtnHighlight;
    property Line           : TColor   read FLine           write FLine           default clBtnShadow;
    property LineShadow     : TColor   read FLineShadow     write FLineShadow     default clBtnHighlight;

  end;

  // menu options
  T_AM2000_MenuOptions = class(TPersistent)
  end;

  T_AM2000_BaseOptions = class(T_AM2000_MenuOptions)
  private
    FItemHeight      : Integer;
    FSeparatorHeight : Integer;
    FTextAlignment   : T_AM2000_Alignment;
    FTitle           : T_AM2000_Title;
    FBackground      : TBitmap;
    FStyle           : T_AM2000_HighlightingStyle;
    FColors          : T_AM2000_Colors;
    FCtl3D           : Boolean;
    FFitToBackground : Boolean;
    FDraggable       : Boolean;
    FMargins         : T_AM2000_Margins;


    function IsBackgroundStored: Boolean;
    function IsColorsStored: Boolean;
    procedure SetBackground(Value: TBitmap);
    procedure SetColors(Value: T_AM2000_Colors);
    procedure SetTitle(Value: T_AM2000_Title);
    procedure SetMargins(Value: T_AM2000_Margins);

  public
    constructor Create;
    destructor Destroy; override;
    procedure Assign(Source: TPersistent); override;

  published
    property ItemHeight      : Integer
      read FItemHeight write FItemHeight default 19;
    property SeparatorHeight : Integer
      read FSeparatorHeight write FSeparatorHeight default 11;
    property Alignment       : T_AM2000_Alignment
      read FTextAlignment write FTextAlignment default taLeftJustify;
    property Title           : T_AM2000_Title
      read FTitle write SetTitle;
    property Background      : TBitmap
      read FBackground write SetBackground stored  IsBackgroundStored;
    property Style           : T_AM2000_HighlightingStyle
      read FStyle write FStyle default hsDefault;
    property Colors          : T_AM2000_Colors
      read FColors write SetColors stored  IsColorsStored;
    property Ctl3D           : Boolean
      read FCtl3D write FCtl3D default True;
    property FitToBackground : Boolean
      read FFitToBackground write FFitToBackground default False;
    property Draggable       : Boolean
      read FDraggable write FDraggable default False;
    property Margins         : T_AM2000_Margins
      read FMargins write SetMargins;

  end;

  T_AM2000_Options = class(T_AM2000_BaseOptions)
  private
    FOpenAnimation   : T_AM2000_Animation;
    FCloseAnimation  : T_AM2000_Animation;
    FTimeout         : Integer;
    FDoubleSpeed     : Boolean;

  public
    constructor Create;
    procedure Assign(Source: TPersistent); override;

  published
    property OpenAnimation   : T_AM2000_Animation read FOpenAnimation   write FOpenAnimation    default anSmart;
    property CloseAnimation  : T_AM2000_Animation read FCloseAnimation  write FCloseAnimation   default anNone;
    property Timeout         : Integer            read FTimeout         write FTimeout          default 20;
    property DoubleSpeed     : Boolean            read FDoubleSpeed     write FDoubleSpeed      default False;

  end;


  // Base Control Options class
  T_AM2000_ControlOptions = class(TPersistent)
  end;

  // TButtonOptions - options for ControlType = ctButton
  T_AM2000_ButtonOptions = class(T_AM2000_ControlOptions)
  private
    FAllowAllUp   : Boolean;
    FBorderFrame  : Boolean;
    FDown         : Boolean;
    FHeight       : Integer;
    FWidth        : Integer;

  public
    constructor Create;

  published
    property AllowAllUp   : Boolean      read FAllowAllUp   write FAllowAllUp   default True;
    property BorderFrame  : Boolean      read FBorderFrame  write FBorderFrame  default True;
    property Down         : Boolean      read FDown         write FDown         default False;
    property Height       : Integer      read FHeight       write FHeight       default 21;
    property Width        : Integer      read FWidth        write FWidth        default 0;

  end;


  // TButtonArrayOptions
  T_AM2000_ButtonArrayOptions = class(T_AM2000_ControlOptions)
  private
    FGlyphs       : TImageList;
    FRows         : Integer;
    FHints        : TStrings;
    FButtonHeight : Integer;
    FButtonWidth  : Integer;
    FItemIndex    : Integer;
    FAllowAllUp   : Boolean;

    procedure SetHints(Value: TStrings);

  public
    LastItemIndex : Integer;

    constructor Create;
    destructor Destroy; override;
//    procedure Assign(Value: TPersistent); override;

  published
    property Glyphs       : TImageList   read FGlyphs       write FGlyphs;
    property Rows         : Integer      read FRows         write FRows         default 3;
    property Hints        : TStrings     read FHints        write SetHints;
    property ButtonHeight : Integer      read FButtonHeight write FButtonHeight default 20;
    property ButtonWidth  : Integer      read FButtonWidth  write FButtonWidth  default 20;
    property ItemIndex    : Integer      read FItemIndex    write FItemIndex    default -1;
    property AllowAllUp   : Boolean      read FAllowAllUp   write FAllowAllUp   default True;

  end;


{  // TEditboxOptions
  T_AM2000_EditboxOptions = class(T_AM2000_ControlOptions)
  private
    FAutoSelect   : Boolean;
    FColor        : TColor;
    FText         : String;
    FHeight       : Integer;
    FReadOnly     : Boolean;

  public
    constructor Create;

  published
    property AutoSelect   : Boolean      read FAutoSelect   write FAutoSelect   default True;
    property Color        : TColor       read FColor        write FColor        default clWindow;
    property Text         : String       read FText         write FText;
    property Height       : Integer      read FHeight       write FHeight       default 21;
    property ReadOnly     : Boolean      read FReadOnly     write FReadOnly     default False;

  end;
}

implementation

uses
  SysUtils;


{ T_AM2000_Margins }

constructor T_AM2000_Margins.Create;
begin
  inherited;

  FLeft:= 25;
  FTop:= 1;
  FRight:= 25;
  FBottom:= 1;
end;

procedure T_AM2000_Margins.Assign(Source: TPersistent);
var
  Src: T_AM2000_Margins;
begin
  if Source is T_AM2000_Margins then begin
    Src:= T_AM2000_Margins(Source);

    FLeft:=      Src.FLeft;
    FTop:=       Src.FTop;
    FRight:=     Src.FRight;
    FBottom:=    Src.FBottom;
    FItemSpace:= Src.FItemSpace;

  end
  else
    inherited;
end;


{ TColors }

constructor T_AM2000_Colors.Create;
begin
  inherited Create;

  FBorder:=         clBtnShadow;
  FMenu:=           clMenu;
  FMenuText:=       clMenuText;
  FMenuShadow:=     clBtnShadow;
  FHighlight:=      clHighlight;
  FHighlightText:=  clHighlightText;
  FDisabledText:=   clBtnShadow;
  FDisabledShadow:= clBtnHighlight;
  FLine:=           clBtnShadow;
  FLineShadow:=     clBtnHighlight;
end;

function T_AM2000_Colors.IsDefaultColors: Boolean;
begin
  Result:= (FBorder =      clBtnShadow)
    and (FMenu =           clMenu)
    and (FMenuText =       clMenuText)
    and (FMenuShadow =     clBtnShadow)
    and (FHighlight =      clHighlight)
    and (FHighlightText =  clHighlightText)
    and (FDisabledText =   clBtnShadow)
    and (FDisabledShadow = clBtnHighlight)
    and (FLine =           clBtnShadow)
    and (FLineShadow =     clBtnHighlight);
end;

procedure T_AM2000_Colors.Assign(Source: TPersistent);
var
  Src: T_AM2000_Colors;
begin
  if Source is T_AM2000_Colors then begin
    Src:= T_AM2000_Colors(Source);
    Border:=         Src.Border;
    Menu:=           Src.Menu;
    MenuText:=       Src.MenuText;
    Highlight:=      Src.Highlight;
    HighlightText:=  Src.HighlightText;
    DisabledText:=   Src.DisabledText;
    DisabledShadow:= Src.DisabledShadow;
    Line:=           Src.Line;
    LineShadow:=     Src.LineShadow;
  end
  else
    inherited;
end;


{ T_AM2000_BaseOptions }

constructor T_AM2000_BaseOptions.Create;
begin
  inherited;

  FItemHeight:= 19;
  FSeparatorHeight:= 11;
  FMargins:= T_AM2000_Margins.Create;
//  FIndent:= 23;
  FCtl3D:= True;

  FTitle:= T_AM2000_Title.Create;
  FColors:= T_AM2000_Colors.Create;
  FBackground:= TBitmap.Create;

end;

destructor T_AM2000_BaseOptions.Destroy;
begin
  FColors.Free;
  FTitle.Free;
  FBackground.Free;
  FMargins.Free;

  inherited;
end;

procedure T_AM2000_BaseOptions.SetBackground(Value: TBitmap);
begin
  FBackground.Assign(Value);
end;

procedure T_AM2000_BaseOptions.SetTitle(Value: T_AM2000_Title);
begin
  FTitle.Assign(Value);
end;

procedure T_AM2000_BaseOptions.SetColors(Value: T_AM2000_Colors);
begin
  FColors.Assign(Value);
end;

procedure T_AM2000_BaseOptions.SetMargins(Value: T_AM2000_Margins);
begin
  FMargins.Assign(Value);
end;

function T_AM2000_BaseOptions.IsBackgroundStored: Boolean;
begin
  Result:= not FBackground.Empty;
end;

function T_AM2000_BaseOptions.IsColorsStored: Boolean;
begin
  Result:= not Colors.IsDefaultColors;
end;

procedure T_AM2000_BaseOptions.Assign(Source: TPersistent);
var
  Src: T_AM2000_BaseOptions;
begin
  if Source is T_AM2000_BaseOptions then begin
    Src:= T_AM2000_BaseOptions(Source);
    
    FItemHeight:=      Src.FItemHeight;
    FSeparatorHeight:= Src.FSeparatorHeight;
    FTextAlignment:=   Src.FTextAlignment;
    FStyle:=           Src.FStyle;
    FCtl3D:=           Src.FCtl3D;
    FFitToBackground:= Src.FFitToBackground;
    FMargins.Assign   (Src.FMargins);
    FTitle.Assign     (Src.FTitle);
    FBackground.Assign(Src.FBackground);
    FColors.Assign    (Src.FColors);
    
  end
  else
    inherited;
end;


{ T_AM2000_Options }

constructor T_AM2000_Options.Create;
begin
  inherited;

  FTimeout:=        20;
  FDoubleSpeed:=    False;
  FOpenAnimation:=  anSmart;
  FCloseAnimation:= anNone;

end;

procedure T_AM2000_Options.Assign(Source: TPersistent);
begin
  inherited;

  if Source is T_AM2000_Options then begin
    FTimeout:=        T_AM2000_Options(Source).FTimeout;
    FDoubleSpeed:=    T_AM2000_Options(Source).FDoubleSpeed;
    FOpenAnimation:=  T_AM2000_Options(Source).FOpenAnimation;
    FCloseAnimation:= T_AM2000_Options(Source).FCloseAnimation;
  end;
end;


{ T_AM2000_ButtonOptions }

constructor T_AM2000_ButtonOptions.Create;
begin
  inherited;

  FAllowAllUp:= True;
  FBorderFrame:= True;
  FHeight:= 21;
end;


{ T_AM2000_ButtonArrayOptions }

constructor T_AM2000_ButtonArrayOptions.Create;
begin
  inherited;

  FHints:= TStringList.Create;
  FButtonWidth:= 20;
  FButtonHeight:= 20;
  FAllowAllUp:= True;
//  FBorderFrame:= True;
  FItemIndex:= -1;
  LastItemIndex:= -1;
  FRows:= 3;
end;

destructor T_AM2000_ButtonArrayOptions.Destroy;
begin
  FHints.Free;
  inherited;
end;

procedure T_AM2000_ButtonArrayOptions.SetHints(Value: TStrings);
begin
  Hints.Assign(Value);
end;


{  T_AM2000_EditboxOptions

constructor T_AM2000_EditboxOptions.Create;
begin
  inherited;

  FAutoSelect:= True;
  FColor:= clWindow;
  FHeight:= 21;
end;

}

end.
